/* $Id: domik.pov,v 1.30 2004/10/13 14:01:26 art Exp $ */

#version 3.6;

#include "colors.inc"
#include "transforms.inc"
#include "woods.inc"
#include "textures.inc"
#include "rad_def.inc"
#include "art_tex.pov"

#include "settings.inc"

#declare generateGrassMesh = 0;

#ifndef(showRadiosity)
	#declare showRadiosity  = 0;
#end

#declare showHata       = 1;
#declare showLavochka   = 1;
#declare showWater      = 1;
#declare showPCMGrass   = 1;
#declare showGiantGrass = 1;
#declare showTerrain    = 1;
#declare showGribi      = 1;
#declare showMostik     = 1;
#declare showClouds     = 1;
#declare showBottle	= 1;
#declare showTrostnik	= 1;

#declare showTerrDetails= 1;
#declare mostikDetails  = 1;
#declare showOkno       = 1;
#declare showDver       = 1;
#declare showNalet      = 1;
#declare grassHi	= 1;
#declare focalBlur	= 1;

#ifndef( radiosityType )
	#declare radiosityType = Radiosity_OutdoorLQ;
#end

#declare scene = 0;
#declare cam = 1;

global_settings {
	assumed_gamma 1.0
	max_trace_level 9
	#if( showRadiosity )
		radiosity {
			// Normal
			// OutdoorLQ
			// OutdoorHQ
			// OutdoorLight
			Rad_Settings( radiosityType, false, false )
		}
	#end
}

#declare R1 = seed(0);

// ----------------------------------------

#switch( cam )
	#case(1) // main view
	camera {
		location  <2, 0.5, -10.0>
		direction 2.0*z
		right     x*image_width/image_height
		look_at   <1.5, 0.5,  0.0>
		#if( focalBlur )
			aperture 0.075
			blur_samples 100
			focal_point <1.5, 0.5, 0.0>
			variance 1/10000
		#end
	} 
	#break
	#case(2) // bird's eye
	camera {
		location  <0, 25, 0>
		direction 2.0*z
		right     x*image_width/image_height
		look_at   <0, 0, 0>
	} 
	#break
	#case(3)
	camera { // domik
		location  <-1, 3.0, -4>
		direction 2.0*z
		right     x*image_width/image_height
		look_at   <-1, 0.5, 0>
	} 
	#break
	#case(4)
	camera {
		location  <0, -0.0, -6>
		direction 2.0*z
		right     x*image_width/image_height
		look_at   <-3.5, -0.6,  0.0>
	} 
	#break 
	#case(5) // over house
	camera {
		location  <-1, 5, 0.0>
		direction 2.0*z
		right     x*image_width/image_height
		look_at   <-1, 0, 0.0>
	} 
	#break
	#case(6) // front house
	camera {
		location  <-1, 0.5, -5.0>
		direction 2.0*z
		right     x*image_width/image_height
		look_at   <-1, 0.5, 0.0>
	} 
	#break
	#case(7) // bottle
	camera {
		location  <2.0, -0.15, -4.0>
		direction 2.0*z
		right     x*image_width/image_height
		look_at   <0, 0.5,  0.0>
		#if( focalBlur )
			aperture 0.055
			blur_samples 100
			focal_point <1.8, -0.15, -3.4>
			variance 1/10000
		#end
	} 
	#break
#end
  
#declare Clouds = union {
   plane {
      y, 260
      texture {
         finish {ambient 0 diffuse 0.7}
         pigment {
            bozo turbulence 1.00 translate 200*y
            color_map {
               [0.5, rgb 1 transmit 1.0]
               [1.0, rgb 1 transmit 0.6]
            }
            scale 0.125
         }
         scale 1500
      }
   }
   plane {y, 200}
   plane {y, 205}
   plane {y, 210}
   
   
   texture {
      finish {ambient 0.2 diffuse 0.7}
      pigment {
         bozo turbulence 0.35 translate 300*y
         color_map {
            [0.6, rgb 1 transmit 1.0]
            [0.9, rgb 1 transmit 0.0]
         }
         scale 10 warp {turbulence 0.7} scale 1/10
         scale 0.125
      }
      scale 2500
   }

   texture {
      finish {ambient 0.4 diffuse 0.5}
      pigment {
         bozo turbulence 0.35 translate 400*y
         color_map {
            [0.7, rgb 1 transmit 1.0]
            [0.9, rgb 1 transmit 0.0]
         }
         scale 10 warp {turbulence 0.7} scale 1/10
         scale 0.125
      }
      scale 2500
   }

   hollow double_illuminate
   scale 1/200
}

#if( showClouds )
        object {Clouds scale <10,30,20>}
#end

background {
   color <0.25,0.35,0.80> // color at horizon
}

fog {
   color <0.40,0.60,1.0> // color at top of sky
   fog_type 2
   distance 200
   fog_offset 0
   fog_alt 60
}

light_source {
	<0,1000,0> rgb 1
	parallel
	point_at <0, 0, 0>
	rotate <-40, 0, 70>
}

light_source {
	<100, 100, -50> rgb 1
	shadowless
}


////////////////////////////////////////////////////
// SHOW BLOCK
////////////////////////////////////////////////////

#if( showHata )
        #debug "Making house...\n"
	#include "hata.pov"
        object { hata }
        #debug "Done!\n"
#end


#if( showLavochka )
        #debug "Making lavochka...\n"
	#include "lavochka.pov"
	object {
		lavochka
		scale 0.75
		rotate y*16
		translate <-1.3, 0.15, -1.0>
	}
	#debug "Done!\n"
#end

#if( showTerrain )
        #debug "Making terrain...\n"
	#include "terrain.pov"
	object {
		terrain
	}
	#debug "Done!\n"
#end

#if( showWater )
        #debug "Making water...\n"
	#include "water.pov"
	object {
		water
	}
	#debug "Done!\n"
#end

#if( showGiantGrass )
        #debug "Making giant grass...\n"
	#include "giantgrass.pov"
	object {
		giantgrass
		texture {
			uv_mapping
			txtGrass scale 0.2
		}
	}
	object {
		backgrass
		texture{
		        uv_mapping
		        txtGrass scale 0.2
		}
	}       
	#debug "Done!\n"
#end

#if( generateGrassMesh )
        #debug "Generating PCM grass...\n"
	#include "pcmgrass.pov"
	#debug "Done!\n"
#else
	#if( showPCMGrass )
	        #debug "Making PCM grass...\n"
		#include "pcmgrass.pov"
		object {
			pcmgrass
			texture{ txtGrass scale 40 }
		}
	        #debug "Done!\n"
	#end
#end

#if( showMostik )
        #debug "Making bridge...\n"
	#include "mostik.pov"
	object {
		MakeMostik()
		rotate y*180
		translate <-1,-1.2,-2.2>
	}
	#debug "Done!\n"
#end

#if( showGribi )
        #debug "Making gribi...\n"
        #include "grib.pov"
	#local gPos = array[3];
	#local gScale = array[3];
	#local gPos[0] = <5.8,10,1.9>;
	#local gPos[1] = <4.5,10,1.4>;
	#local gPos[2] = <6.0,10,1.3>;
	#local gScale[0] = 0.7;
	#local gScale[1] = 0.5;
	#local gScale[2] = 0.3;
	#local gNum = 3;
	#local gNorm = <0,0,0>;
	
	#while( gNum > 0 )
		#local gNum = gNum - 1;
		#local inter = trace( terrain, gPos[ gNum ], -y, gNorm );
		#if( vlength( gNorm ) != 0 )
			object { grib() scale gScale[ gNum ] translate inter }
		#end
	#end
	#debug "Done!\n"
#end

#if( showBottle )
	#include "bottle.pov"
#end

#if( showTrostnik )
	#include "trostnik.pov"
#end

