/* $Id: grib.pov,v 1.7 2004/10/11 06:29:24 art Exp $ */

#version 3.5;

#include "colors.inc"
#include "functions.inc"
#include "art_tex.pov"

// ----------------------------------------
#declare single = 1;

#ifndef( scene )
        #declare scene = 1;
#end

#if( scene )

global_settings {
  assumed_gamma 1.0
}

#if( single )
        camera {
        	location	<0.0, 1.1, -7.0>
        	direction	1.5*z
        	right		x*image_width/image_height
        	look_at		<0.0, 2.0,  0.0>
        }
#else
        camera {
        	location	<7.0, 1.1, -8.0>
        	direction	1.5*z
        	right		x*image_width/image_height
        	look_at		<1.5, 2.0,  0.0>
        }
#end

sky_sphere {
	pigment {
		gradient y
		color_map {
			[0.0 rgb <0.6,0.7,1.0>]
			[0.7 rgb <0.0,0.1,0.8>]
		}
	}
}

light_source {
	<0, 0, 0>            // light's position (translated below)
	color rgb <1, 1, 1>  // light's color
	translate <-10, 30, -20>
}

light_source {
	<0, 0, 0>            // light's position (translated below)
	color rgb <1, 1, 1>  // light's color
	translate <-3, 1, -2>
}

// ----------------------------------------


plane {
	y, 0
	pigment { color rgb <0.5,0.7,0.0> }
}
#end

//////////////////////////////////////////
#declare nozhRad = 0.05;
#declare nozhLen = 3;
#declare nozhRadK = 0.4;
#declare nozhDistort = 0.3;
#declare shlRad = 1.5;
#declare gribSeed = seed( 127 );

#macro grib()

union {

// nozhka

#local fn_nozhRad = function {
	sin( (y+0.2)*pi*1.1 )
}

#local fn_nozhBasic = function {
        sqrt( pow(x,2) + pow(z,2) ) - ( 1*nozhRad + nozhRad*nozhRadK*fn_nozhRad(0,y,0) )
}

#local fn_nozhNoised = function {
        fn_nozhBasic(x,y,z) + 0.01*f_agate(x*50,y*10,z*50)
}

#local nozhDistX = 100*rand( rand( gribSeed ) );
#local nozhDistZ = 100*rand( rand( gribSeed ) );

#local fn_nozhkaDistort = function { fn_nozhNoised(x + nozhDistort * (0.5-f_bozo( nozhDistX, y*3, nozhDistZ )) * sin(y*pi), y ,z + nozhDistort * (0.5-f_bozo(y*3,nozhDistX,nozhDistZ)) * sin(y*pi) ) }
#local fn_nozhkaFinal = function { fn_nozhkaDistort(x,y,z) }

isosurface {
	function { fn_nozhkaFinal( x,y,z ) }
	
	contained_by { box { <-1,0,-1>, <1, 1, 1> } }  // container shape
	threshold 0.0                     // optional threshold value for isosurface [0.0]
	max_gradient 10.817

	pigment {
	        gradient y
	        pigment_map {
	                
	                [0.05 pig_earth ]
	                [0.45 color rgb <0.8, 0.9, 0.6> ]
	        }
        }
	finish { specular 0.0 }
        
        scale nozhLen
}

// shlyapka
//#local fn_shlyapka = function { shlRad + y - shlRad/2*sin( atan( ( z + shlRad*0.2*f_bozo(x*4,0,z*4)) / ( x + shlRad*0.2*f_bozo(x*4,0,z*4)) )*100 ) - shlRad*0.1*f_agate(x*2,y*2,z*2) };

#local fn_shlyapka = function { shlRad + y - shlRad/2*sin( atan( ( z + shlRad*0.2*f_bozo(x*4,0,z*4)) / ( x + shlRad*0.2*f_bozo(x*4,0,z*4)) )*50 ) - shlRad*0.1*f_agate(x*2,y*2,z*2) };

intersection {
	isosurface {
		function { f_sphere(x,y,z,shlRad) - 0.05 * f_noise3d(x*3,y*3,z*3) - 0.01 * f_agate(x*2,y*2,z*2) }
		contained_by {
			box {
				<-shlRad-.1, 0, -shlRad-.1>, <shlRad+.1, shlRad+.1, shlRad+.1>
			}
		}
		max_gradient 1.344
		pigment {
			bozo
			color_map {
				[0.6 Red*0.8]
				[0.62 White]
			}
			scale 0.2
		}
		finish {
			specular 0.1
		}
	}
	

	#local fn_agate = function {
		pigment {
			agate
			color_map {
				[0.1	White]
				[0.15	Black]
			}
		}
	}
	#local fnShl1 = 100*rand(gribSeed);

	difference {
		isosurface {
			function { f_sphere( x,y,z, shlRad+0.15 )/* + 0.11*fn_agate(x/2+fnShl1,y/2,z/2).gray*/ }
			contained_by {
				box { <-shlRad-.1, 0, -shlRad-.1>, <shlRad+.1, shlRad+.1, shlRad+.1> }
			}
			max_gradient 1
		}
		isosurface {
			function { fn_shlyapka(x,y,z) } 
			contained_by { sphere{ 0, shlRad*0.99 } }
			threshold 1.5*shlRad
			max_gradient 100
			open

			scale y*0.7
		}
		pigment { 
			color rgb <0.8, 0.9, 0.6>
		}
		finish { ambient 0.2 diffuse 0.5 specular 0.3 }
	}

	rotate x*15*rand(gribSeed)
	rotate y*360*rand(gribSeed)
	scale <1,0.5,1>
	translate y*nozhLen
}

}

#end

#if( scene )
        #if( single )
                object {
                    grib()
                }
        #else
                #local i = 7;
                #local sc = 1;
                #local p = <-shlRad*2, 0, 0>;
                
                #while( i > 0 )
                        #declare gribSeed = seed( rand( gribSeed ) );
                        object {
                	        grib()
                	        scale sc
                	        translate p
                        }
                        #local p = p + x * shlRad * 2 * sc;
                        #local sc = 2 * sc / 3;
                        #local i = i - 1;
                #end
        #end
#end
